@@ -7,7 +7,7 @@ use Encode ();
 use JSON::MaybeXS ();
 use constant DEBUG => $ENV{TELEGRAM_BOTAPI_DEBUG} || 0;
 
-our $VERSION = "0.07";
+our $VERSION = "0.08";
 my $json; # for debugging purposes, only defined when DEBUG = 1
 
 BEGIN {
@@ -200,11 +200,14 @@ sub api_request
     unless (($is_lwp ? $tx->is_success : $tx->success) && $response && $response->{ok})
     {
         $response ||= {};
+        # Handle old errors supplied by ancient Mojolicious versions: in some conditions,
+        # `$tx->error` returned a string instead of the expected hash reference. See issue #16.
+        my $error = $response->{description} || ($is_lwp ? $tx->status_line :
+            ((ref ($tx->error || {}) ? $tx->error : { message => $tx->error }) || {})->{message});
         # Print either the error returned by the API or the HTTP status line.
         Carp::confess
             "ERROR: ", ($response->{error_code} ? "code " . $response->{error_code} . ": " : ""),
-            $response->{description} ? $response->{description} : $is_lwp ?
-                $tx->status_line : ($tx->error || {})->{message} || "something went wrong!"
+            $error || "something went wrong!";
     }
     DEBUG and _dprintf "END REQUEST to /%s :: %s", $method, scalar localtime;
     $response
@@ -338,6 +341,11 @@ L<WWW::Telegram::BotAPI> implements the following methods.
 
 Creates a new L<WWW::Telegram::BotAPI> instance.
 
+B<WARNING:> you should only create one instance of this module and reuse it when needed. Calling
+C<new> each time you run an async request causes unexpected behavior with L<Mojo::UserAgent> and
+won't work correctly. See also
+L<issue #13 on GitHub|https://github.com/Robertof/perl-www-telegram-botapi/issues/13>.
+
 C<%options> may contain the following:
 
 =over 4
@@ -573,7 +581,8 @@ yourself as shown in the L</"SYNOPSIS">.
 
 L<LWP::UserAgent>, L<Mojo::UserAgent>,
 L<https://core.telegram.org/bots/api>, L<https://core.telegram.org/bots>,
-L<example implementation of a Telegram bot|https://git.io/vlOK0>
+L<example implementation of a Telegram bot|https://git.io/vlOK0>,
+L<example implementation of an async Telegram bot|https://git.io/vDrwL>
 
 =head1 AUTHOR
 
